@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,8 +21,8 @@
 
 using namespace KAddressBookGrantlee;
 ContactGrantleeAddressObject::ContactGrantleeAddressObject(const KContacts::Address &address, QObject *parent)
-    : QObject(parent),
-      mAddress(address)
+    : QObject(parent)
+    , mAddress(address)
 {
 }
 
